@@ -16,7 +16,7 @@ __contributors__ = [
     "Lai Han",
 ]
 __license__ = "MIT"
-__version__ = "0.30.0"
+__version__ = "0.31.1"
 
 import base64
 import calendar
@@ -178,7 +178,8 @@ def _build_ssl_context(
     if hasattr(context, "check_hostname"):
         context.check_hostname = not disable_ssl_certificate_validation
 
-    context.load_verify_locations(ca_certs)
+    if not disable_ssl_certificate_validation:
+        context.load_verify_locations(ca_certs)
 
     if cert_file:
         context.load_cert_chain(cert_file, key_file, key_password)
@@ -953,6 +954,10 @@ def proxy_info_from_url(url, method="http", noproxy=None):
     url = urllib.parse.urlparse(url)
 
     proxy_type = 3  # socks.PROXY_TYPE_HTTP
+    if url.scheme == "socks4":
+        proxy_type = 1  # socks.PROXY_TYPE_SOCKS4
+    elif url.scheme == "socks5" or url.scheme == "socks":
+        proxy_type = 2  # socks.PROXY_TYPE_SOCKS5
     pi = ProxyInfo(
         proxy_type=proxy_type,
         proxy_host=url.hostname,
